@@ -25,6 +25,7 @@ import (
 	"bytes"
 	"crypto/rand"
 	"encoding/binary"
+	"errors"
 	"fmt"
 	"net"
 	"strings"
@@ -447,54 +448,18 @@ func testNewV6KSortable(t *testing.T) {
 }
 
 func testNewV7(t *testing.T) {
-	t.Run("InvalidPrecision", testNewV7InvalidPrecision)
-
-	for _, p := range []Precision{NanosecondPrecision, MicrosecondPrecision, MillisecondPrecision} {
-		t.Run(p.String(), func(t *testing.T) {
-			t.Run("Basic", makeTestNewV7Basic(p))
-			t.Run("Basic10000000", makeTestNewV7Basic10000000(p))
-			t.Run("DifferentAcrossCalls", makeTestNewV7DifferentAcrossCalls(p))
-			t.Run("StaleEpoch", makeTestNewV7StaleEpoch(p))
-			t.Run("FaultyRand", makeTestNewV7FaultyRand(p))
-			t.Run("ShortRandomRead", makeTestNewV7ShortRandomRead(p))
-			t.Run("ClockSequenceBehaviors", makeTestNewV7ClockSequenceBehaviors(p))
-			t.Run("KSortable", makeTestNewV7KSortable(p))
-		})
-	}
-
-	t.Run("ClockSequence", testNewV7ClockSequence)
+	t.Run("Basic", makeTestNewV7Basic())
+	t.Run("Basic10000000", makeTestNewV7Basic10000000())
+	t.Run("DifferentAcrossCalls", makeTestNewV7DifferentAcrossCalls())
+	t.Run("StaleEpoch", makeTestNewV7StaleEpoch())
+	t.Run("FaultyRand", makeTestNewV7FaultyRand())
+	t.Run("ShortRandomRead", makeTestNewV7ShortRandomRead())
+	t.Run("KSortable", makeTestNewV7KSortable())
 }
 
-func testNewV7InvalidPrecision(t *testing.T) {
-	t.Run("NewV7", func(t *testing.T) {
-		defer func() {
-			if r := recover(); r == nil {
-				t.Fatal("call did not panic")
-			}
-		}()
-
-		NewV7(255)
-	})
-
-	t.Run("getV7ClockSequence", func(t *testing.T) {
-		defer func() {
-			if r := recover(); r == nil {
-				t.Fatal("expected panic did not occur")
-			}
-		}()
-
-		g := NewGen()
-		g.epochFunc = func() time.Time {
-			return time.Unix(0, 0)
-		}
-
-		g.getV7ClockSequence(255)
-	})
-}
-
-func makeTestNewV7Basic(p Precision) func(t *testing.T) {
+func makeTestNewV7Basic() func(t *testing.T) {
 	return func(t *testing.T) {
-		u, err := NewV7(p)
+		u, err := NewV7()
 		if err != nil {
 			t.Fatal(err)
 		}
@@ -507,20 +472,16 @@ func makeTestNewV7Basic(p Precision) func(t *testing.T) {
 	}
 }
 
-func makeTestNewV7Basic10000000(p Precision) func(t *testing.T) {
+func makeTestNewV7Basic10000000() func(t *testing.T) {
 	return func(t *testing.T) {
 		if testing.Short() {
 			t.Skip("skipping test in short mode.")
 		}
 
-		if p == MillisecondPrecision {
-			t.Skip("skipping test, see: https://github.com/uuid6/uuid6-ietf-draft/issues/40")
-		}
-
 		g := NewGen()
 
 		for i := 0; i < 10000000; i++ {
-			u, err := g.NewV7(p)
+			u, err := g.NewV7()
 			if err != nil {
 				t.Fatal(err)
 			}
@@ -534,15 +495,15 @@ func makeTestNewV7Basic10000000(p Precision) func(t *testing.T) {
 	}
 }
 
-func makeTestNewV7DifferentAcrossCalls(p Precision) func(t *testing.T) {
+func makeTestNewV7DifferentAcrossCalls() func(t *testing.T) {
 	return func(t *testing.T) {
 		g := NewGen()
 
-		u1, err := g.NewV7(p)
+		u1, err := g.NewV7()
 		if err != nil {
 			t.Fatal(err)
 		}
-		u2, err := g.NewV7(p)
+		u2, err := g.NewV7()
 		if err != nil {
 			t.Fatal(err)
 		}
@@ -552,7 +513,7 @@ func makeTestNewV7DifferentAcrossCalls(p Precision) func(t *testing.T) {
 	}
 }
 
-func makeTestNewV7StaleEpoch(p Precision) func(t *testing.T) {
+func makeTestNewV7StaleEpoch() func(t *testing.T) {
 	return func(t *testing.T) {
 		g := &Gen{
 			epochFunc: func() time.Time {
@@ -560,11 +521,11 @@ func makeTestNewV7StaleEpoch(p Precision) func(t *testing.T) {
 			},
 			rand: rand.Reader,
 		}
-		u1, err := g.NewV7(p)
+		u1, err := g.NewV7()
 		if err != nil {
 			t.Fatal(err)
 		}
-		u2, err := g.NewV7(p)
+		u2, err := g.NewV7()
 		if err != nil {
 			t.Fatal(err)
 		}
@@ -574,7 +535,7 @@ func makeTestNewV7StaleEpoch(p Precision) func(t *testing.T) {
 	}
 }
 
-func makeTestNewV7FaultyRand(p Precision) func(t *testing.T) {
+func makeTestNewV7FaultyRand() func(t *testing.T) {
 	return func(t *testing.T) {
 		g := &Gen{
 			epochFunc: time.Now,
@@ -582,36 +543,35 @@ func makeTestNewV7FaultyRand(p Precision) func(t *testing.T) {
 				readToFail: 0, // fail immediately
 			},
 		}
-		u, err := g.NewV7(p)
+		u, err := g.NewV7()
 		if err == nil {
 			t.Errorf("got %v, nil error", u)
 		}
 	}
 }
 
-func makeTestNewV7ShortRandomRead(p Precision) func(t *testing.T) {
+func makeTestNewV7ShortRandomRead() func(t *testing.T) {
 	return func(t *testing.T) {
 		g := &Gen{
 			epochFunc: time.Now,
 			rand:      bytes.NewReader([]byte{42}),
 		}
-		u, err := g.NewV7(p)
+		u, err := g.NewV7()
 		if err == nil {
 			t.Errorf("got %v, nil error", u)
 		}
 	}
 }
 
-func makeTestNewV7KSortable(p Precision) func(t *testing.T) {
+func makeTestNewV7KSortable() func(t *testing.T) {
 	return func(t *testing.T) {
 		uuids := make([]UUID, 10)
 		for i := range uuids {
-			u, err := NewV7(p)
-			testErrCheck(t, "NewV6()", "", err)
+			u, err := NewV7()
+			testErrCheck(t, "NewV7()", "", err)
 
 			uuids[i] = u
-
-			time.Sleep(p.Duration())
+			time.Sleep(time.Millisecond)
 		}
 
 		for i := 1; i < len(uuids); i++ {
@@ -624,68 +584,6 @@ func makeTestNewV7KSortable(p Precision) func(t *testing.T) {
 	}
 }
 
-// to get 100% code coverage we need to do some glass box testing
-func makeTestNewV7ClockSequenceBehaviors(p Precision) func(t *testing.T) {
-	return func(t *testing.T) {
-		t.Run("TimeWarp", func(t *testing.T) {
-			g := NewGen()
-			tn := time.Now()
-			unix := uint64(tn.Unix()) + 100
-			nsec := uint64(tn.Nanosecond())
-
-			g.v7LastTime = unix
-			g.v7LastSubsec = nsec
-
-			_, err := g.NewV7(p)
-			testErrCheck(t, "g.NewV7()", "", err)
-
-			if g.v7ClockSequence != 1 {
-				t.Fatalf("g.v7ClockSequence = %d, want 1", g.v7ClockSequence)
-			}
-		})
-
-		t.Run("NominalTime", func(t *testing.T) {
-			g := NewGen()
-			g.v7ClockSequence = 100
-
-			tn := time.Now()
-			unix := uint64(tn.Unix()) - 100
-			nsec := uint64(tn.Nanosecond())
-
-			g.v7LastTime = unix
-			g.v7LastSubsec = nsec
-
-			_, err := g.NewV7(p)
-			testErrCheck(t, "g.NewV7()", "", err)
-
-			if g.v7ClockSequence != 0 {
-				t.Fatalf("g.v7ClockSequence = %d, want 0", g.v7ClockSequence)
-			}
-		})
-
-		t.Run("Overflow", func(t *testing.T) {
-			if testing.Short() {
-				t.Skip("skipping test in short mode.")
-			}
-
-			wantErrStr := fmt.Sprintf("generating %s precision UUIDv7s too fast: internal clock sequence would roll over", p.String())
-
-			g := NewGen()
-
-			g.epochFunc = func() time.Time {
-				return time.Unix(0, 0)
-			}
-
-			g.v7ClockSequence = maxSeq14 + 1
-			g.v7LastTime = uint64(g.epochFunc().Unix())
-			g.v7LastSubsec = uint64(g.epochFunc().Nanosecond())
-
-			_, err := g.NewV7(p)
-			testErrCheck(t, "g.NewV7()", wantErrStr, err)
-		})
-	}
-}
-
 func testNewV7ClockSequence(t *testing.T) {
 	if testing.Short() {
 		t.Skip("skipping test in short mode.")
@@ -698,26 +596,26 @@ func testNewV7ClockSequence(t *testing.T) {
 	sleepDur := int(time.Second) - nsec
 	time.Sleep(time.Duration(sleepDur))
 
-	u1, err := g.NewV7(MillisecondPrecision)
+	u1, err := g.NewV7()
 	if err != nil {
 		t.Fatalf("failed to generate V7 UUID #1: %v", err)
 	}
 
-	u2, err := g.NewV7(MillisecondPrecision)
+	u2, err := g.NewV7()
 	if err != nil {
 		t.Fatalf("failed to generate V7 UUID #2: %v", err)
 	}
 
 	time.Sleep(time.Millisecond)
 
-	u3, err := g.NewV7(MillisecondPrecision)
+	u3, err := g.NewV7()
 	if err != nil {
 		t.Fatalf("failed to generate V7 UUID #3: %v", err)
 	}
 
 	time.Sleep(time.Second)
 
-	u4, err := g.NewV7(MillisecondPrecision)
+	u4, err := g.NewV7()
 	if err != nil {
 		t.Fatalf("failed to generate V7 UUID #3: %v", err)
 	}
@@ -744,65 +642,98 @@ func testNewV7ClockSequence(t *testing.T) {
 	}
 }
 
-func TestPrecision_String(t *testing.T) {
+func TestDefaultHWAddrFunc(t *testing.T) {
 	tests := []struct {
-		p    Precision
-		want string
+		n  string
+		fn func() ([]net.Interface, error)
+		hw net.HardwareAddr
+		e  string
 	}{
 		{
-			p:    NanosecondPrecision,
-			want: "nanosecond",
+			n: "Error",
+			fn: func() ([]net.Interface, error) {
+				return nil, errors.New("controlled failure")
+			},
+			e: "controlled failure",
 		},
 		{
-			p:    MillisecondPrecision,
-			want: "millisecond",
+			n: "NoValidHWAddrReturned",
+			fn: func() ([]net.Interface, error) {
+				s := []net.Interface{
+					{
+						Index:        1,
+						MTU:          1500,
+						Name:         "test0",
+						HardwareAddr: net.HardwareAddr{1, 2, 3, 4},
+					},
+					{
+						Index:        2,
+						MTU:          1500,
+						Name:         "lo0",
+						HardwareAddr: net.HardwareAddr{5, 6, 7, 8},
+					},
+				}
+
+				return s, nil
+			},
+			e: "uuid: no HW address found",
 		},
 		{
-			p:    MicrosecondPrecision,
-			want: "microsecond",
-		},
-		{
-			p:    0xff,
-			want: "unknown",
+			n: "ValidHWAddrReturned",
+			fn: func() ([]net.Interface, error) {
+				s := []net.Interface{
+					{
+						Index:        1,
+						MTU:          1500,
+						Name:         "test0",
+						HardwareAddr: net.HardwareAddr{1, 2, 3, 4},
+					},
+					{
+						Index:        2,
+						MTU:          1500,
+						Name:         "lo0",
+						HardwareAddr: net.HardwareAddr{5, 6, 7, 8, 9, 0},
+					},
+				}
+
+				return s, nil
+			},
+			hw: net.HardwareAddr{5, 6, 7, 8, 9, 0},
 		},
 	}
 
 	for _, tt := range tests {
-		t.Run(tt.want, func(t *testing.T) {
-			if got := tt.p.String(); got != tt.want {
-				t.Errorf("got = %s, want %s", got, tt.want)
+		t.Run(tt.n, func(t *testing.T) {
+			// set the netInterfaces variable (function) for the test
+			// and then set it back to default in the deferred function
+			netInterfaces = tt.fn
+			defer func() {
+				netInterfaces = net.Interfaces
+			}()
+
+			var hw net.HardwareAddr
+			var err error
+
+			hw, err = defaultHWAddrFunc()
+
+			if len(tt.e) > 0 {
+				if err == nil {
+					t.Fatalf("defaultHWAddrFunc() error = <nil>, should contain %q", tt.e)
+				}
+
+				if !strings.Contains(err.Error(), tt.e) {
+					t.Fatalf("defaultHWAddrFunc() error = %q, should contain %q", err.Error(), tt.e)
+				}
+
+				return
 			}
-		})
-	}
-}
 
-func TestPrecision_Duration(t *testing.T) {
-	tests := []struct {
-		p    Precision
-		want time.Duration
-	}{
-		{
-			p:    NanosecondPrecision,
-			want: time.Nanosecond,
-		},
-		{
-			p:    MillisecondPrecision,
-			want: time.Millisecond,
-		},
-		{
-			p:    MicrosecondPrecision,
-			want: time.Microsecond,
-		},
-		{
-			p:    0xff,
-			want: 0,
-		},
-	}
+			if err != nil && tt.e == "" {
+				t.Fatalf("defaultHWAddrFunc() error = %q, want <nil>", err.Error())
+			}
 
-	for _, tt := range tests {
-		t.Run(tt.p.String(), func(t *testing.T) {
-			if got := tt.p.Duration(); got != tt.want {
-				t.Errorf("got = %s, want %s", got, tt.want)
+			if !bytes.Equal(hw, tt.hw) {
+				t.Fatalf("hw = %#v, want %#v", hw, tt.hw)
 			}
 		})
 	}
